@@ -1,6 +1,7 @@
 # coding: utf-8
 
-from __future__ import unicode_literals
+from __future__ import absolute_import, unicode_literals
+
 from .genty import genty
 from .genty_dataset import genty_dataset
 from .genty_dataset import genty_dataprovider
